@@ -1,10 +1,14 @@
-from base import QuickbooksBaseObject, Ref, QuickbooksManagedObject
+from six import python_2_unicode_compatible
+from .base import QuickbooksBaseObject, Ref, QuickbooksManagedObject, QuickbooksTransactionEntity
 
 
+@python_2_unicode_compatible
 class BudgetDetail(QuickbooksBaseObject):
     class_dict = {
         "AccountRef": Ref,
-        "CustomerRef": Ref
+        "CustomerRef": Ref,
+        "ClassRef": Ref,
+        "DepartmentRef": Ref,
     }
 
     def __init__(self):
@@ -14,12 +18,15 @@ class BudgetDetail(QuickbooksBaseObject):
 
         self.AccountRef = None
         self.CustomerRef = None
+        self.ClassRef = None
+        self.DepartmentRef = None
 
-    def __unicode__(self):
+    def __str__(self):
         return str(self.Amount)
 
 
-class Budget(QuickbooksManagedObject):
+@python_2_unicode_compatible
+class Budget(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: The Budget endpoint allows you to retrieve the current state of budgets already set up in the user's
     company file. A budget allows for an amount to be assigned on a monthly, quarterly, or annual basis for a specific
@@ -27,7 +34,7 @@ class Budget(QuickbooksManagedObject):
     should be spent against that account or customer in the give time period.
     """
 
-    class_dict = {
+    list_dict = {
         "BudgetDetail": BudgetDetail,
     }
 
@@ -42,8 +49,8 @@ class Budget(QuickbooksManagedObject):
         self.BudgetEntryType = ""
         self.Active = True
 
-        self.BudgetDetail = None
+        self.BudgetDetail = []
 
-    def __unicode__(self):
+    def __str__(self):
         return self.Name
 
